==> jc-1.4.0.tar.gz: gnu/java/io/ObjectIdentityWrapper.h <==
// public class gnu.java.io.ObjectIdentityWrapper

// class file dependencies
// @dep_class 15fcba763592e7e gnu_java_io_ObjectIdentityWrapper
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_io_ObjectIdentityWrapper_H_
#define _JC_gnu_java_io_ObjectIdentityWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_refs	_jc_gnu_java_io_ObjectIdentityWrapper$sub_refs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs	_jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$refs	_jc_gnu_java_io_ObjectIdentityWrapper$refs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$nonrefs	_jc_gnu_java_io_ObjectIdentityWrapper$nonrefs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$object	_jc_gnu_java_io_ObjectIdentityWrapper$object;

typedef const struct _jc_gnu_java_io_ObjectIdentityWrapper$vmethods	_jc_gnu_java_io_ObjectIdentityWrapper$vmethods;
typedef const struct _jc_gnu_java_io_ObjectIdentityWrapper$vtable	_jc_gnu_java_io_ObjectIdentityWrapper$vtable;
typedef const struct _jc_gnu_java_io_ObjectIdentityWrapper$vtype	_jc_gnu_java_io_ObjectIdentityWrapper$vtype;

// Constructors
extern void _jc_gnu_java_io_ObjectIdentityWrapper$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_gnu_java_io_ObjectIdentityWrapper$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_gnu_java_io_ObjectIdentityWrapper$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_ObjectIdentityWrapper$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_ObjectIdentityWrapper$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_io_ObjectIdentityWrapper$method_info$hashCode$53152098849316df;
extern _jc_method _jc_gnu_java_io_ObjectIdentityWrapper$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_io_ObjectIdentityWrapper$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *);
};

// Vtable
struct _jc_gnu_java_io_ObjectIdentityWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_io_ObjectIdentityWrapper$vmethods	gnu_java_io_ObjectIdentityWrapper;
};

// Vtype
struct _jc_gnu_java_io_ObjectIdentityWrapper$vtype {
	_jc_type			type;
	_jc_gnu_java_io_ObjectIdentityWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_refs {
	struct _jc_java_lang_Object$object	*object;
};

// Reference instance fields (object)
struct _jc_gnu_java_io_ObjectIdentityWrapper$refs {
    _jc_gnu_java_io_ObjectIdentityWrapper$sub_refs	gnu_java_io_ObjectIdentityWrapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_ObjectIdentityWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs	gnu_java_io_ObjectIdentityWrapper;
};

// Object instance structure
struct _jc_gnu_java_io_ObjectIdentityWrapper$object {
	_jc_gnu_java_io_ObjectIdentityWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_ObjectIdentityWrapper$vtype	*vtype;
	_jc_gnu_java_io_ObjectIdentityWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_ObjectIdentityWrapper$vtype _jc_gnu_java_io_ObjectIdentityWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_ObjectIdentityWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_ObjectIdentityWrapper$class_object;

#endif	/* _JC_gnu_java_io_ObjectIdentityWrapper_H_ */

==> jc-1.4.6.tar.gz: gnu/java/io/ObjectIdentityWrapper.h <==
// public class gnu.java.io.ObjectIdentityWrapper

// class file dependencies
// @dep_class 15fcba763592e7e gnu_java_io_ObjectIdentityWrapper
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_io_ObjectIdentityWrapper_H_
#define _JC_gnu_java_io_ObjectIdentityWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_refs	_jc_gnu_java_io_ObjectIdentityWrapper$sub_refs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs	_jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$refs	_jc_gnu_java_io_ObjectIdentityWrapper$refs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$nonrefs	_jc_gnu_java_io_ObjectIdentityWrapper$nonrefs;
typedef struct _jc_gnu_java_io_ObjectIdentityWrapper$object	_jc_gnu_java_io_ObjectIdentityWrapper$object;

typedef const struct _jc_gnu_java_io_ObjectIdentityWrapper$vmethods	_jc_gnu_java_io_ObjectIdentityWrapper$vmethods;
typedef const struct _jc_gnu_java_io_ObjectIdentityWrapper$vtable	_jc_gnu_java_io_ObjectIdentityWrapper$vtable;
typedef const struct _jc_gnu_java_io_ObjectIdentityWrapper$vtype	_jc_gnu_java_io_ObjectIdentityWrapper$vtype;

// Constructors
extern void _jc_gnu_java_io_ObjectIdentityWrapper$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_io_ObjectIdentityWrapper$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_io_ObjectIdentityWrapper$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_ObjectIdentityWrapper$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_io_ObjectIdentityWrapper$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_io_ObjectIdentityWrapper$method_info$hashCode$53152098849316df;
extern _jc_method _jc_gnu_java_io_ObjectIdentityWrapper$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_io_ObjectIdentityWrapper$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_io_ObjectIdentityWrapper$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_io_ObjectIdentityWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_io_ObjectIdentityWrapper$vmethods	gnu_java_io_ObjectIdentityWrapper;
};

// Vtype
struct _jc_gnu_java_io_ObjectIdentityWrapper$vtype {
	_jc_type			type;
	_jc_gnu_java_io_ObjectIdentityWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_refs {
	struct _jc_java_lang_Object$object	*object;
};

// Reference instance fields (object)
struct _jc_gnu_java_io_ObjectIdentityWrapper$refs {
    _jc_gnu_java_io_ObjectIdentityWrapper$sub_refs	gnu_java_io_ObjectIdentityWrapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_ObjectIdentityWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_io_ObjectIdentityWrapper$sub_nonrefs	gnu_java_io_ObjectIdentityWrapper;
};

// Object instance structure
struct _jc_gnu_java_io_ObjectIdentityWrapper$object {
	_jc_gnu_java_io_ObjectIdentityWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_ObjectIdentityWrapper$vtype	*vtype;
	_jc_gnu_java_io_ObjectIdentityWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_ObjectIdentityWrapper$vtype _jc_gnu_java_io_ObjectIdentityWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_ObjectIdentityWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_ObjectIdentityWrapper$class_object;

#endif	/* _JC_gnu_java_io_ObjectIdentityWrapper_H_ */
